@@ -1,4 +1,4 @@
-"""changing violations value to Longtext
+"""Changing violations value to Longtext
 
 Revision ID: 368929fa3075
 Revises: 54ca0bd9bc1e
@@ -15,8 +15,8 @@ import sqlalchemy as sa
 
 
 def upgrade():
-    op.alter_column('violations', 'value', type_=sa.Text(4294967295), nullable=False)
+    op.alter_column('violations', 'value', type_=sa.Text(length=4294967295), nullable=True)
 
 
 def downgrade():
-    op.alter_column('violations', 'value', type_=sa.Text, nullable=False)
+    op.alter_column('violations', 'value', type_=sa.Text(), nullable=True)
